@@ -22,7 +22,7 @@ def type_link(link, file_size=1024, sleep_time=2):
     """ type_link() will download a link, and then deturmine it's file type using magic numbers.
     """
 
-    #log( "Attempting to type link: '{0}' (using filesize: {1})".format(link,file_size) )
+    log( "Attempting to type link: '{0}' (using filesize: {1})".format(link,file_size) )
 
     success = False
     file_type = ""
@@ -38,10 +38,10 @@ def type_link(link, file_size=1024, sleep_time=2):
         while(error_count < 5):
             try:
                 payload = urllib2.urlopen(req,timeout=5).read(file_size)
-                #log( "Successfully downloaded the first {0} bytes of '{1}'.".format(file_size, link) )
+                log( "Successfully downloaded the first {0} bytes of '{1}'.".format(file_size, link) )
                 break
             except Exception, e:
-                #log( "Error within type_link while trying to download {0} bytes from URL:\n\t{1}\n".format(link,str(e)) )
+                log( "Error within type_link while trying to download {0} bytes from URL:\n\t{1}\n".format(link,str(e)) )
                 if str(e) != 'time out':
                     raise Exception(e)
                 else:
@@ -52,7 +52,7 @@ def type_link(link, file_size=1024, sleep_time=2):
         success = True
         
     except Exception, e:
-        #log( "An error has occured in the type_link() function:\n\tURL: {0}\n\tError: {1}".format(link,str(e)) )
+        log( "An error has occured in the type_link() function:\n\tURL: {0}\n\tError: {1}".format(link,str(e)) )
         pass
     
     return success, file_type
@@ -85,9 +85,9 @@ def check_match(domain_url, link, allowed_domains):
 
             site_match = False
 
-    #log( "check_match(): link='{0}'".format(link) )
-    #log( "check_match(): site_match='{0}', domain_url_root='{1}', link_root='{2}'".format(site_match, domain_url_root, link_root) )
-    #log( "" )
+    log( "check_match(): link='{0}'".format(link) )
+    log( "check_match(): site_match='{0}', domain_url_root='{1}', link_root='{2}'".format(site_match, domain_url_root, link_root) )
+    log( "" )
 
 #    #if ( (len(link) >= 7 and link[0:7].lower() == "http://") or
 #    #     (len(link) >= 8 and link[0:8].lower() == "https://") or
@@ -249,10 +249,10 @@ def get_page_links(domain_url, url, allowed_domains, file_size=1024, sleep_time=
         except Exception, e:
             links = []
             sucess = False
-            #log( "An error occurred in get_page_links():\n\tURL: {0}\n\tError: {1}".format(url,str(e)) )
+            log( "get_page_links():Exception: \n\tURL: {0}\n\tError: {1}".format(url,str(e)) )
 
     except Exception, e:
-        #log( 'Exception: {0}'.format(str(e)) )
+        log( 'get_page_links():Exception: {0}'.format(str(e)) )
         pass
     
     #log( "Found {0} links from URL: '{1}', bad_link = {2}.".format(len(links),url,bad_link) )
